USE tempdb
GO
CREATE TABLE title (
  title_id   int      IDENTITY PRIMARY KEY
, unit_price int      NOT NULL
)
CREATE TABLE orders (
  orders_id  int      IDENTITY PRIMARY KEY
, title_id   int      NOT NULL
    FOREIGN KEY REFERENCES title(title_id)
, qty        smallint NOT NULL
, price      bigint   NULL
)
GO
IF OBJECT_ID('tr_OrdersUpdate') IS NOT NULL
  DROP TRIGGER tr_OrdersUpdate
GO
CREATE TRIGGER tr_OrdersUpdate
  ON orders
  FOR UPDATE
AS
  IF NOT UPDATE(qty)
    RETURN

  BEGIN TRAN

  DECLARE @ERR int
  DECLARE @title_id int, @unit_price int,
    @orders_id int, @qty smallint

  /* ŵ  orders_id, title_id    (qty) Ȯ */
  SELECT @orders_id = orders_id, @title_id = title_id, @qty = qty
    FROM inserted

  /* ܰ(title.unit_price) Ȯ */
  SELECT @unit_price = unit_price
    FROM title
    WHERE title_id = @title_id

  /* ܰ *  ݾ  */
  UPDATE orders
    SET price = @unit_price * @qty
    WHERE orders_id = @orders_id

  SET @ERR = @@ERROR
  IF @ERR <> 0  GOTO ERROR

  COMMIT TRAN
  RETURN
ERROR:
  DECLARE @error_msg nvarchar(400)
  SET @error_msg =
    dbo.sfn_MakeErrMsg('tr_OrdersUpdate', @ERR, DEFAULT)
  RAISERROR( @error_msg, 16, 1 )
  ROLLBACK TRAN
GO